@@ -6,21 +6,21 @@ from xml.etree import ElementTree
 
 
 if 'PySide2' in sys.modules:
-    from PySide2.QtGui import QFontDatabase, QColor
+    from PySide2.QtGui import QFontDatabase, QColor, QGuiApplication, QPalette
     from PySide2.QtWidgets import QAction, QColorDialog
     from PySide2.QtUiTools import QUiLoader
     from PySide2.QtCore import Qt
     _resource = os.path.join('resources', 'resource_pyside2_rc.py')
 
 elif 'PySide6' in sys.modules:
-    from PySide6.QtGui import QFontDatabase, QAction, QColor
+    from PySide6.QtGui import QFontDatabase, QAction, QColor, QGuiApplication, QPalette
     from PySide6.QtWidgets import QColorDialog
     from PySide6.QtUiTools import QUiLoader
     from PySide6.QtCore import Qt
     _resource = os.path.join('resources', 'resource_pyside6_rc.py')
 
 elif 'PyQt5' in sys.modules:
-    from PyQt5.QtGui import QFontDatabase, QColor
+    from PyQt5.QtGui import QFontDatabase, QColor, QGuiApplication, QPalette
     from PyQt5.QtWidgets import QAction, QColorDialog
     from PyQt5.QtCore import Qt
     from PyQt5 import uic
@@ -53,8 +53,17 @@ def build_stylesheet(theme='', invert_secondary=False, resources=[], extra={}):
 
     stylesheet = env.get_template(template)
 
+    theme.setdefault('font_family', 'Roboto')
+    theme.setdefault('danger', '#dc3545')
+    theme.setdefault('warning', '#ffc107')
+    theme.setdefault('success', '#17a2b8')
+
     theme.update(extra)
 
+    default_palette = QGuiApplication.palette()
+    default_palette.setColor(QPalette.PlaceholderText, QColor(*[int(theme['primaryColor'][i:i + 2], 16) for i in range(1, 6, 2)] + [92]))
+    QGuiApplication.setPalette(default_palette)
+
     return stylesheet.render(**theme)
 
 
@@ -210,7 +219,6 @@ class QtStyleTools:
     # ----------------------------------------------------------------------
     def add_menu_theme(self, parent, menu):
         """"""
-
         for theme in ['default'] + list_themes():
             action = QAction(parent)
             action.setText(theme)
@@ -329,7 +337,12 @@ class QtStyleTools:
                        'secondaryTextColor']
 
         self.custom_colors = {v: os.environ[f'PYSIDEMATERIAL_{v.upper()}'] for v in self.colors}
-        self.dock_theme = QUiLoader().load(os.path.join(os.path.dirname(__file__), 'dock_theme.ui'), parent)
+
+        if 'PySide2' in sys.modules or 'PySide6' in sys.modules:
+            self.dock_theme = QUiLoader().load(os.path.join(os.path.dirname(__file__), 'dock_theme.ui'))
+        elif 'PyQt5' in sys.modules:
+            self.dock_theme = uic.loadUi(os.path.join(os.path.dirname(__file__), 'dock_theme.ui'))
+
         parent.addDockWidget(Qt.LeftDockWidgetArea, self.dock_theme)
         self.dock_theme.setFloating(True)
 
